@@ -25,10 +25,10 @@
 
 #define RNP_VERSION_MAJOR 0
 #define RNP_VERSION_MINOR 18
-#define RNP_VERSION_PATCH 0
+#define RNP_VERSION_PATCH 1
 
-#define RNP_VERSION_STRING "0.18.0"
-#define RNP_VERSION_STRING_FULL "0.18.0"
+#define RNP_VERSION_STRING "0.18.1"
+#define RNP_VERSION_STRING_FULL "0.18.1"
 
 #define RNP_VERSION_COMMIT_TIMESTAMP 0
 
@@ -51,17 +51,17 @@ static_assert(RNP_VERSION_MAJOR <= RNP_VERSION_COMPONENT_MASK &&
               "version components must be within range");
 
 /* Crypto backend as it was used during the build */
-#define RNP_BACKEND "botan"
-#define RNP_BACKEND_VERSION "3.9.0"
+#define RNP_BACKEND "openssl"
+#define RNP_BACKEND_VERSION "3.5.4"
 
 /* Enabled RNP features: will be appended by CMake */
 #define RNP_HAS_AEAD 1
-#define RNP_HAS_AEAD_EAX 1
+#define RNP_HAS_AEAD_EAX 0
 #define RNP_HAS_AEAD_OCB 1
 #define RNP_HAS_BLOWFISH 1
 #define RNP_HAS_BRAINPOOL 1
 #define RNP_HAS_CAST5 1
 #define RNP_HAS_IDEA 1
 #define RNP_HAS_RIPEMD160 1
-#define RNP_HAS_SM2 1
-#define RNP_HAS_TWOFISH 1
+#define RNP_HAS_SM2 0
+#define RNP_HAS_TWOFISH 0
